@@ -43,7 +43,9 @@ impl VisitMut for CompressDeclaration {
 
         if let DeclarationName::Ident(Ident { value, .. }) = &declaration.name {
             match &*value.to_lowercase() {
-                "padding" | "margin" | "inset" if declaration.value.len() > 1 => {
+                "padding" | "margin" | "inset" | "scroll-margin" | "scroll-padding"
+                    if declaration.value.len() > 1 =>
+                {
                     let top = declaration.value.get(0);
                     let right = declaration
                         .value
